==> flink-runtime-1.16.2-sources.jar: org/apache/flink/runtime/taskexecutor/TaskExecutorRegistrationRejection.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.flink.runtime.taskexecutor;

import org.apache.flink.runtime.registration.RegistrationResponse;
import org.apache.flink.runtime.resourcemanager.ResourceManager;

/** Rejection response from the {@link ResourceManager} for the {@link TaskExecutor}. */
public class TaskExecutorRegistrationRejection extends RegistrationResponse.Rejection {
    private static final long serialVersionUID = -7447810107639038319L;

    private final String reason;

    public TaskExecutorRegistrationRejection(String reason) {
        this.reason = reason;
    }

    public String getReason() {
        return reason;
    }

    @Override
    public String toString() {
        return "Rejected TaskExecutor registration at the ResourceManager because: " + reason;
    }
}

==> flink-runtime_2.11-1.13.0-sources.jar: org/apache/flink/runtime/taskexecutor/TaskExecutorRegistrationRejection.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.flink.runtime.taskexecutor;

import org.apache.flink.runtime.registration.RegistrationResponse;
import org.apache.flink.runtime.resourcemanager.ResourceManager;

/** Rejection response from the {@link ResourceManager} for the {@link TaskExecutor}. */
public class TaskExecutorRegistrationRejection extends RegistrationResponse.Rejection {
    private static final long serialVersionUID = -7447810107639038319L;

    private final String reason;

    public TaskExecutorRegistrationRejection(String reason) {
        this.reason = reason;
    }

    public String getReason() {
        return reason;
    }

    @Override
    public String toString() {
        return "Rejected TaskExecutor registration at the ResourceManger because: " + reason;
    }
}
